@@ -1,8 +1,11 @@
 from typing import Callable, Type
+
 from scintillant.apimodels import SkillResponse
 from scintillant.apimodels.types import SkillRequestType, SkillResponseType
 from scintillant.outs import Dictionary
 
+from loguru import logger
+
 
 class ContextUpdater:
     states = {}  # state_name: state_func
@@ -21,7 +24,9 @@ class ContextUpdater:
 
     @property
     def next_state(self):
-        return self.context['state']
+        if 'state' in self.context:
+            return self.context['state']
+        return None
 
     @next_state.setter
     def next_state(self, func: Callable):
@@ -41,15 +46,23 @@ class ContextUpdater:
             self._initial_state_()
         # In case the user already has a state.
         else:
-            state = self.context.get('state')
+            state = self.next_state.split('ContextUpdater_', maxsplit=1)[1]
             if state not in self.states:
                 raise Exception(f"State {state} not registered!")
             else:
                 self.states[state](self)
 
     def get_response(self) -> SkillResponseType:
+        logger.debug("Executing state {} from User {} | Update data: {}".format(
+            self.next_state,
+            self.data.user,
+            self.data
+        ))
         self.execute_state()
         self.response.context = self.context
+        logger.info("Getting response: {}".format(self.response))
+        if not self.response.out_text and self.response.status not in ['redirect', 'exit']:
+            logger.error('Response out_text field is None inside non-action state!')
         return self.response
 
     def _initial_state_(self):
